local uci = require "luci.model.uci".cursor()
local ds = require "luci.dispatcher"
local wa = require "luci.tools.webadmin"
local sys = require "luci.sys"


m = Map("modbus-i2c-slave", translate("Modbus Slave"))

section_global = m:section(TypedSection, "global", translate("Enable/ Disable"))
section_global.anonymous = false
section_global.addremove = false
section_global.name = "global"

option_enabled = section_global:option(Flag, "enabled", translate("Enabled"),
    translate("Enable Modbus Slave"))
option_enabled.rmempty=false
option_enabled.default="1"


s1 = m:section(TypedSection, "modbus_device", translate("Modbus Slave"), "")
s1.anonymous = true
s1.addremove = false

conn_type = s1:option(ListValue, "type", translate("Type"))
conn_type:value("rtu", translate("Modbus RTU"))
conn_type:value("tcp", translate("Modbus TCP"))
conn_type.default = "tcp"

host = s1:option(Value, "host", translate("IP address"))
host.datatype = "ip4addr"
host.default = "127.0.0.1"
host:depends("type", "tcp")

port = s1:option(Value, "port", translate("Port"))
port.datatype = "port"
port.default = "502"
port:depends("type", "tcp")

no_of_connections = s1:option(Value, "no_of_connections", "Number Of Modbus-Master Connections", translate("Maximum number of simultaneous Modbus-Master connections"))
no_of_connections.datatype = "integer"
no_of_connections:depends("type", "tcp")

serial_port = s1:option(Value, "serial_port", translate("Serial Port"))
serial_port.datatype = "string"
serial_port.default = "/dev/ttyS0"
serial_port:depends("type", "rtu")

baudrate = s1:option(ListValue, "baudrate", translate("Baud rate"))
baudrate:value("300", "300")
baudrate:value("1200", "1200")
baudrate:value("2400", "2400")
baudrate:value("4800", "4800")
baudrate:value("9600", "9600")
baudrate:value("19200", "19200")
baudrate:value("38400", "38400")
baudrate:value("57600", "57600")
baudrate:value("115200", "115200")
baudrate.default = "115200"
baudrate:depends("type", "rtu")

parity = s1:option(ListValue, "parity", translate("Parity"))
parity:value("N", translate("None"))
parity:value("E", translate("Even"))
parity:value("O", translate("Odd"))
parity.default = "N"
parity:depends("type", "rtu")

databits = s1:option(ListValue, "databits", translate("Data bits"))
databits:value("5", "5")
databits:value("6", "6")
databits:value("7", "7")
databits:value("8", "8")
databits.default = "8"
databits:depends("type", "rtu")

stopbits = s1:option(ListValue, "stopbits", translate("Stop bits"))
stopbits:value("1", "1")
stopbits:value("2", "2")
stopbits.default = "1"
stopbits:depends("type", "rtu")

mode = s1:option(ListValue, "mode", translate("Interface Type"))
mode:value("RS232", "RS232")
mode:value("RS485", "RS485")
mode.default = "RS232"
mode:depends("type", "rtu")

slave_id = s1:option(Value, "slave_id", translate("Slave Id"))
slave_id.default = "1"

analog_type = s1:option(ListValue, "analog_type", translate("Analog Input Register Type Setting (I2C)"))
analog_type:value("1", translate("-50 To 400 °C"))
analog_type:value("2", translate("4 To 20mA"))
analog_type:value("3", translate("0 To 10V"))
analog_type.default = "1"

s2 = m:section(TypedSection, "modbus_address", translate("Modbus Slave Register Address"), "")
s2.anonymous = true
s2.addremove = false

start_output_bit_addr = s2:option(Value, "start_output_bit_addr", translate("Start Address Of Binary Output"))
start_output_bit_addr.datatype = "integer"
start_output_bit_addr.default = "1"

start_input_bit_addr = s2:option(Value, "start_input_bit_addr", translate("Start Address Of Binary Input"))
start_input_bit_addr.datatype = "integer"
start_input_bit_addr.default = "1"

start_input_register_addr = s2:option(Value, "start_input_register_addr", translate("Start Address Of Analog Input"))
start_input_register_addr.datatype = "integer"
start_input_register_addr.default = "1"


return m
